<?php
// y[Ẅꗗ擾B
$dp = opendir($MOWIKI_DATA);
while ($fname = readdir($dp)) {
  if (!is_dir($MOWIKI_DATA.$fname)) { // fBNgȊȌꍇ
	// t@Cۑ
	list($pname, $tmp) = split('\.', $fname);

	// y[W̃^Cgϐɓ
	$gDef['page_names'][$pname] = filemtime($MOWIKI_DATA.$fname);
  }
}
closedir($dp);

// print_r($gDef['page_names']);
if (count($gDef['page_names']) > '0') {
  // \[g
  arsort($gDef['page_names']);

  // ʕ\
  $i = 1;
  foreach($gDef['page_names'] as $key => $body) {
	if ($i > $MOWIKI_LIST_MAX) { // sȏ゠ꍇ
	  continue;
	}

	// XVԂt^
	$file_meantime = (time() - $gDef['page_names'][$key]);
	if ($file_meantime > 86400) {
	  $mean = floor($file_meantime / 86400).'d';
	} else if ($file_meantime > 3600) {
	  $mean = floor($file_meantime / 3600).'h';
	} else if ($file_meantime > 60) {
	  $mean = floor($file_meantime / 60).'m';
	} else {
	  $mean = $file_meantime.'s';
	}


	// ꗗ\쐬
	$gOut['body'] .= '<a href="'.$_SERVER['PHP_SELF'].'?a=V&title='.$key.'">'
	  .decode($key).'</a> '.$mean.'<br>'."\n";

	$i++;
  }
}
?>